@@ -3,7 +3,7 @@
 **
 ** Copyright (C) Nate Robins, 1997
 **               Michael Wimmer, 1999
-**               Milan Ikits, 2003-2007
+**               Milan Ikits, 2002-2008
 **
 ** visualinfo is a small utility that displays all available visuals,
 ** aka. pixelformats, in an OpenGL system along with renderer version
@@ -86,12 +86,12 @@ char* display = NULL;
 int visual = -1;
 
 FILE* file = 0;
-GLContext ctx;
 
 int 
 main (int argc, char** argv)
 {
   GLenum err;
+  GLContext ctx;
 
   /* ---------------------------------------------------------------------- */
   /* parse arguments */
@@ -161,10 +161,13 @@ main (int argc, char** argv)
   fprintf(file, "OpenGL version string: %s\n", glGetString(GL_VERSION));
   fprintf(file, "OpenGL extensions (GL_): \n");
   PrintExtensions((char*)glGetString(GL_EXTENSIONS));
+
+#ifndef GLEW_NO_GLU
   /* GLU extensions */
   fprintf(file, "GLU version string: %s\n", gluGetString(GLU_VERSION));
   fprintf(file, "GLU extensions (GLU_): \n");
   PrintExtensions((char*)gluGetString(GLU_EXTENSIONS));
+#endif
 
   /* ---------------------------------------------------------------------- */
   /* extensions string */
@@ -1056,7 +1059,7 @@ GLboolean CreateContext (GLContext* ctx)
   aglDestroyPixelFormat(pf);
   /*aglSetDrawable(ctx, GetWindowPort(wnd));*/
   ctx->octx = aglGetCurrentContext();
-  if (NULL == aglSetCurrentContext(ctx->ctx)) return GL_TRUE;
+  if (GL_FALSE == aglSetCurrentContext(ctx->ctx)) return GL_TRUE;
   return GL_FALSE;
 }
 
